@@ -13,11 +13,11 @@ print.vharlse <- function(x, digits = max(3L, getOption("digits") - 3L), ...) {
   # phihat_mat <- switch(
   #   x$type,
   #   "const" = {
-  #     split.data.frame(x$coefficients[-(3 * x$m + 1),], gl(3, x$m)) %>% 
+  #     split.data.frame(x$coefficients[-(3 * x$m + 1),], gl(3, x$m)) |> 
   #       lapply(t)
   #   },
   #   "none" = {
-  #     split.data.frame(x$coefficients, gl(3, x$m)) %>% 
+  #     split.data.frame(x$coefficients, gl(3, x$m)) |> 
   #       lapply(t)
   #   }
   # )
@@ -99,8 +99,8 @@ print.summary.vharlse <- function(x, digits = max(3L, getOption("digits") - 3L),
   dim_data <- ncol(x$covmat)
   dim_design <- nrow(coef_mat) / dim_data
   coef_mat <- 
-    coef_mat %>% 
-    separate(term, into = c("term", "variable"), sep = "\\.") %>% 
+    coef_mat |> 
+    separate(term, into = c("term", "variable"), sep = "\\.") |> 
     split.data.frame(f = gl(dim_data, dim_design))
   if (signif_code) {
     sig_star <- numeric(dim_design)
